@@ -1,3 +1,4 @@
+import time
 from typing import TYPE_CHECKING, Any, Optional, Type, cast
 
 import structlog
@@ -93,6 +94,8 @@ class CeleryReceiver:
         signals.bind_extra_task_metadata.send(
             sender=self.receiver_task_prerun, task=task, logger=logger
         )
+        # Record the start time so we can log the task duration later.
+        task.request._django_structlog_started_at = time.monotonic_ns()
         logger.info("task_started", task=task.name)
 
     def receiver_task_retry(
@@ -105,12 +108,15 @@ class CeleryReceiver:
         logger.warning("task_retrying", reason=reason)
 
     def receiver_task_success(
-        self, result: Optional[str] = None, **kwargs: Any
+        self, result: Optional[str] = None, sender: Optional[Any] = None, **kwargs: Any
     ) -> None:
         signals.pre_task_succeeded.send(
             sender=self.receiver_task_success, logger=logger, result=result
         )
-        logger.info("task_succeeded")
+
+        log_vars: dict[str, Any] = {}
+        self.add_duration_ms(sender, log_vars)
+        logger.info("task_succeeded", **log_vars)
 
     def receiver_task_failure(
         self,
@@ -122,17 +128,31 @@ class CeleryReceiver:
         *args: Any,
         **kwargs: Any,
     ) -> None:
+        log_vars: dict[str, Any] = {}
+        self.add_duration_ms(sender, log_vars)
         throws = getattr(sender, "throws", ())
         if isinstance(exception, throws):
             logger.info(
                 "task_failed",
                 error=str(exception),
+                **log_vars,
             )
         else:
             logger.exception(
                 "task_failed",
                 error=str(exception),
                 exception=exception,
+                **log_vars,
+            )
+
+    @classmethod
+    def add_duration_ms(
+        cls, task: Optional[Type[Any]], log_vars: dict[str, Any]
+    ) -> None:
+        if task and hasattr(task.request, "_django_structlog_started_at"):
+            started_at: int = task.request._django_structlog_started_at
+            log_vars["duration_ms"] = round(
+                (time.monotonic_ns() - started_at) / 1_000_000
             )
 
     def receiver_task_revoked(
