@@ -21,6 +21,7 @@ from asgiref import sync
 from django.core.exceptions import PermissionDenied
 from django.core.signals import got_request_exception
 from django.http import Http404, StreamingHttpResponse
+from django.utils.functional import SimpleLazyObject
 
 from .. import signals
 from ..app_settings import app_settings
@@ -39,6 +40,7 @@ else:
 if TYPE_CHECKING:  # pragma: no cover
     from types import TracebackType
 
+    from django.contrib.auth.base_user import AbstractBaseUser
     from django.http import HttpRequest, HttpResponse
 
 logger = structlog.getLogger(__name__)
@@ -179,8 +181,6 @@ class RequestMiddleware:
         structlog.contextvars.clear_contextvars()
 
     def prepare(self, request: "HttpRequest") -> None:
-        from ipware import get_client_ip  # type: ignore[import-untyped]
-
         request_id = get_request_header(
             request, "x-request-id", "HTTP_X_REQUEST_ID"
         ) or str(uuid.uuid4())
@@ -191,8 +191,8 @@ class RequestMiddleware:
         self.bind_user_id(request)
         if correlation_id:
             structlog.contextvars.bind_contextvars(correlation_id=correlation_id)
-        ip, _ = get_client_ip(request)
-        structlog.contextvars.bind_contextvars(ip=ip)
+        if app_settings.IP_LOGGING_ENABLED:
+            self.bind_ip(request)
         log_kwargs = {
             "request": self.format_request(request),
             "user_agent": request.META.get("HTTP_USER_AGENT"),
@@ -202,6 +202,13 @@ class RequestMiddleware:
         )
         logger.info("request_started", **log_kwargs)
 
+    @classmethod
+    def bind_ip(cls, request: "HttpRequest") -> None:
+        from ipware import get_client_ip  # type: ignore[import-untyped]
+
+        ip, _ = get_client_ip(request)
+        structlog.contextvars.bind_contextvars(ip=ip)
+
     @staticmethod
     def format_request(request: "HttpRequest") -> str:
         return f"{request.method} {request.get_full_path()}"
@@ -209,7 +216,14 @@ class RequestMiddleware:
     @staticmethod
     def bind_user_id(request: "HttpRequest") -> None:
         user_id_field = app_settings.USER_ID_FIELD
-        if hasattr(request, "user") and request.user is not None and user_id_field:
+        if not user_id_field or not hasattr(request, "user"):
+            return
+
+        session_was_accessed = (
+            request.session.accessed if hasattr(request, "session") else None
+        )
+
+        if request.user is not None:
             user_id = None
             if hasattr(request.user, user_id_field):
                 user_id = getattr(request.user, user_id_field)
@@ -217,6 +231,17 @@ class RequestMiddleware:
                     user_id = str(user_id)
             structlog.contextvars.bind_contextvars(user_id=user_id)
 
+        if session_was_accessed is False:
+            """using SessionMiddleware but user was never accessed, must reset accessed state"""
+            user = request.user
+
+            def get_user() -> Any:
+                request.session.accessed = True
+                return user
+
+            request.user = cast("AbstractBaseUser", SimpleLazyObject(get_user))
+            request.session.accessed = False
+
     def process_got_request_exception(
         self, sender: Type[Any], request: "HttpRequest", **kwargs: Any
     ) -> None:
